==> hermes-5.9.0.11.tar.gz: hermes-5.9.0.11/app/controllers/hermes/api/dmo/signup_user_notification_preferences_controller.rb <==
# frozen_string_literal: true
# checker Api::Dmo::HermesController avant d'ajouter des méthodes
module Hermes
  module Api
    module Dmo
      class SignupUserNotificationPreferencesController < Hermes::Api::Dmo::ApplicationController
        skip_before_filter :verify_authenticity_token, :set_user, :allow_true_user, :check_if_log_as
        skip_after_action :log_action

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $regex
        ].freeze

        ACCEPTABLE_PARAMS = %w[
          email
          notification_key
          want_to_be_subscribed
          used_at
        ].freeze

        REGEX_PARAMS = %w[
          email
        ].freeze

        MUTATE_PARAMS = %i[
          email
          notification_key
          want_to_be_subscribed
        ].freeze

        def mutate_params
          MUTATE_PARAMS
        end 

        def create
          @instance = @model.new(mutate_valid_params)
          return respond_with_errors(@instance) unless @instance.save

          render(jsonapi: @instance, serializer: @serializer, status: :created)
        end

        def create_multiple_preferences
          email = params[:data][:attributes][:email]
          created_instance_ids = []
          done_keys = []

          params[:data][:attributes][:notifs].each do|notif|
            notif[:email] = email
            done_keys.push(notif[:notification_key])
            notif_valid_params = ActiveModelSerializers::Deserialization.jsonapi_parse!(
              {"data"=>{"attributes"=> notif }},
              only: mutate_params, key_transform: :unaltered
            ).merge(@additional_params)

            instance = Hermes::SignupUserNotificationPreference.new(notif_valid_params)
            return respond_with_errors(instance) unless instance.save
            created_instance_ids.push (instance.id.to_s)
        end
         
          render(json: {email: email, signup_user_notification_preference_ids: created_instance_ids}, status: :created)
        end

        def user_notifications_list 
          render(json: NOTIFICATION_KEYS[:user])
        end 

      end
    end
  end
end

==> hermes-6.0.1.22.tar.gz: hermes-6.0.1.22/app/controllers/hermes/api/dmo/signup_user_notification_preferences_controller.rb <==
# frozen_string_literal: true
# checker Api::Dmo::HermesController avant d'ajouter des méthodes
module Hermes
  module Api
    module Dmo
      class SignupUserNotificationPreferencesController < Hermes::Api::Dmo::ApplicationController
        skip_before_filter :verify_authenticity_token, :set_user, :allow_true_user, :check_if_log_as
        skip_after_action :log_action

        class << self
          def mutate_params
            {
              email: {type: 'String'},
              notification_key: {type: 'String'},
              want_to_be_subscribed: {type: 'Boolean'},
            }
          end 
      
          def acceptable_params
            {
              used_at: {type: 'DateTime'},
            }.merge(self.mutate_params).merge(super)
          end 
      
          def valid_operators
            %w[$in $nin $ne $gt $gte $lt $lte $regex]
          end
      
          def regex_params
            {

            }
          end 
        end
        
        def create
          @instance = @model.new(mutate_valid_params)
          return respond_with_errors(@instance) unless @instance.save

          render(jsonapi: @instance, serializer: @serializer, status: :created)
        end

        def create_multiple_preferences
          email = params[:data][:attributes][:email]
          created_instance_ids = []
          done_keys = []

          params[:data][:attributes][:notifs].each do|notif|
            notif[:email] = email
            done_keys.push(notif[:notification_key])
            notif_valid_params = ActiveModelSerializers::Deserialization.jsonapi_parse!(
              {"data"=>{"attributes"=> notif }},
              only: self.class.mutate_params.keys, key_transform: :unaltered
            ).merge(@additional_params)

            instance = Hermes::SignupUserNotificationPreference.new(notif_valid_params)
            return respond_with_errors(instance) unless instance.save
            created_instance_ids.push (instance.id.to_s)
        end
         
          render(json: {email: email, signup_user_notification_preference_ids: created_instance_ids}, status: :created)
        end

        def user_notifications_list 
          render(json: NOTIFICATION_KEYS[:user])
        end 

      end
    end
  end
end
